@@ -42,7 +42,7 @@ class TorchSkeleton:
             if not joint_info['children']: # If joint is at edge, do not add to kinematic_chain
                 continue
 
-            joint_info['offsets'] = torch.Tensor(joint_info['offsets']).reshape(3, 1)
+            joint_info['offsets'] = torch.Tensor(joint_info['offsets'], device=self.device).reshape(3, 1)
 
             if 'channels' in joint_info:
                 if joint_name is self.root_name:
@@ -56,8 +56,8 @@ class TorchSkeleton:
 
         offsets = []
         for joint in kinematic_chain:
-            offsets.append(kinematic_chain[joint]['offsets'].squeeze().numpy())
-        self._offset_arr = torch.Tensor(np.array(offsets).squeeze()).to(self.device)
+            offsets.append(kinematic_chain[joint]['offsets'].squeeze())
+        self._offset_arr = torch.stack(offsets)
         return kinematic_chain
 
     def forward_kinematics(self, root_positions: torch.Tensor, rotations: torch.Tensor, rot_repr='quaternion'):
